@@ -1,4 +1,5 @@
 # Copyright (C) 2007 Karline Soetaert (K.Soetaert@nioo.knaw.nl)
+# Revised by James Orr, 2012-01-17
 #
 # This file is part of seacarb.
 #
@@ -38,15 +39,31 @@ TC = T + tk               # TC [C]; T[K]
 # Dissociation constant of Si(OH)4 on total scale - DOE 1994 - correct for mol/(kg-H2O)->mol/kg soln
 #--------------------------------------------------------------
 Io  <- 19.924*S/(1000-1.005*S)                     # ionic strenght, mol/kg-H2O     # ionic strength
-lnK <- 117.385 + 3.5913*sqrt(Io) - 1.5998*Io + 0.07871*Io*Io +
+
+	#	*** J. Orr (15 Jan 2013): Formulation changed to be on the SWS scale (without later conversion)
+	                                                     
+
+	# From J. C. Orr on 15 Jan 2013:
+	# The formulation below was a modified version of Millero (1995) where Dickson et al. (2007) subtracted 0.015
+        # from Millero's original constant (117.40) to give 117.385 (the 2nd term above). BUT Dickson's reason for that 
+        # operation was to "convert--approximately--from theSWS pH scale (including HF) used by Millero (1995) to the 'total' 
+        # scale ...". 
+        # This subtraction of 0.015 to switch from the SWS to Total scale is not good for 2 reasons:
+        # (1) The 0.015 value is inexact (not constant), e.g., it is 0.022 at T=25, S=35, P=0;
+	# (2) It makes no sense to switch to the Total scale when just below you switch back to the SWS scale.
+        # The best solution is to reestablish the original equation (SWS scale) and delete the subsequent scale conversion.
+
+#lnK <- 117.385 + 3.5913*sqrt(Io) - 1.5998*Io + 0.07871*Io*Io +
+lnK <- 117.40  + 3.5913*sqrt(Io) - 1.5998*Io + 0.07871*Io*Io +
       (-8904.2 - 458.79*sqrt(Io) + 188.74*Io - 12.1652*Io*Io)/TC +
       (-19.334)*log(TC)+log(1-0.001005*S)
 
 Ksi <- exp(lnK)
 
 # ---- Conversion from Total scale to seawater scale before pressure corrections
-factor <- kconv(S=S, T=T, P=rep(0,nK))$ktotal2SWS
-Ksi <- Ksi * factor
+#      *** JCO: This is no longer necessary: with original formulation (Millero, 1995), Kw is on "seawater scale"!
+#factor <- kconv(S=S, T=T, P=rep(0,nK))$ktotal2SWS
+#Ksi <- Ksi * factor
 
 Ksi <- Pcorrect(Kvalue=Ksi, Ktype="Ksi", T=T, S=S, P=P, pHscale="SWS")
 
